@@ -1,4 +1,4 @@
-#!/bin/sh
+#!/bin/bash
 # find out where the build script is located
 tdir=`echo "$0" | sed 's%[\\/][^\\/][^\\/]*$%%'`
 test "x$tdir" = "x$0" && tdir=.
@@ -37,11 +37,13 @@ elif [ -e ${PKG}${VERMAJ}${VERMIN}.tar.bz2 ] ; then
 fi
 
 export src_orig_pkg_name=${PKG}${VERMAJ}${VERMIN}.tar.${src_orig_pkg_ext}
+export src_orig_pkg_name2=zcrypt29.tar.bz2
 export src_pkg_name=${FULLPKG}-src.tar.bz2
 export src_patch_name=${FULLPKG}.patch
 export bin_pkg_name=${FULLPKG}.tar.bz2
 
 export src_orig_pkg=${topdir}/${src_orig_pkg_name}
+export src_orig_pkg2=${topdir}/${src_orig_pkg_name2}
 export src_pkg=${topdir}/${src_pkg_name}
 export src_patch=${topdir}/${src_patch_name}
 export bin_pkg=${topdir}/${bin_pkg_name}
@@ -67,9 +69,18 @@ mkdirs() {
   mkdir -p ${srcinstdir}
 )}
 
+fixup() {
+  thedir=$1
+  (cd ${thedir} && \
+  tar xvjf ${src_orig_pkg2} ; \
+  cp -f zcrypt29/crypt.h . && \
+  cp -f zcrypt29/crypt.c .
+)}
+
 prep() {
   (cd ${topdir} && \
   tar xv${opt_decomp}f ${src_orig_pkg} ; \
+  fixup ${srcdir}
   cd ${topdir} && \
   patch -p0 < ${src_patch} && \
   mkdirs && \
@@ -106,12 +117,13 @@ install() {
   if [ -f ${instdir}${prefix}/share/info/dir ] ; then \
     rm ${instdir}${prefix}/share/info/dir ; \
   fi && \
-  if [ ! -d ${instdir}${prefix}/share/doc/${PKG}-${VER} ]; then \
-    mkdir -p ${instdir}${prefix}/share/doc/${PKG}-${VER} ; \
-  fi && \
-  if [ ! -d ${instdir}${prefix}/share/doc/Cygwin ]; then \
-    mkdir -p ${instdir}${prefix}/share/doc/Cygwin ; \
-  fi && \
+  for d in ${instdir}${prefix}/share/doc/${PKG}-${VER} \
+           ${instdir}${prefix}/share/doc/Cygwin \
+           ${instdir}${prefix}/share/doc/${PKG}-${VER}/zcrypt29 ; do \
+    if [ ! -d ${d} ] ; then \
+      mkdir -p ${d} ; \
+    fi ; \
+  done && \
   templist=""; \
   for f in ${srcdir}/BUGS ${srcdir}/CHANGES ${srcdir}/LICENSE \
            ${srcdir}/README ${srcdir}/TODO ${srcdir}/WHATSNEW \
@@ -124,6 +136,18 @@ install() {
     /usr/bin/install -m 644 $templist \
          ${instdir}${prefix}/share/doc/${PKG}-${VER} ;
   fi && \
+  templist=""; \
+  for f in ${srcdir}/zcrypt29/LICENSE      ${srcdir}/zcrypt29/README.CR \
+           ${srcdir}/zcrypt29/USexport.msg ${srcdir}/zcrypt29/WHERE \
+           ${srcdir}/zcrypt29/file_id.diz  ${srcdir}/zcrypt29.msg ; do \
+    if [ -f $f ] ; then \
+      templist="$templist $f"; \
+    fi ; \
+  done && \
+  if [ ! "x$templist" = "x" ]; then \
+    /usr/bin/install -m 644 $templist \
+         ${instdir}${prefix}/share/doc/${PKG}-${VER}/zcrypt29 ;
+  fi && \
   if [ -f ${srcdir}/CYGWIN-PATCHES/${PKG}.README ]; then \
     /usr/bin/install -m 644 ${srcdir}/CYGWIN-PATCHES/${PKG}.README \
       ${instdir}${prefix}/share/doc/Cygwin/${PKG}-${VER}.README ; \
@@ -146,6 +170,8 @@ mkpatch() {
   (cd ${srcdir} && \
   tar xv${opt_decomp}f ${src_orig_pkg} ;\
   mv ${PKG}-${VER} ../${PKG}-${VER}-orig && \
+  temp=`(cd ../${PKG}-${VER}-orig ; pwd)` && \
+  fixup $temp
   cd ${topdir} && \
   diff -urN -x '.build' -x '.inst' -x '.sinst' \
     ${PKG}-${VER}-orig ${PKG}-${VER} > \
@@ -156,6 +182,7 @@ mkpatch() {
 spkg() {
   (mkpatch && \
   cp ${src_orig_pkg} ${srcinstdir}/${src_orig_pkg_name} && \
+  cp ${src_orig_pkg2} ${srcinstdir}/${src_orig_pkg_name2} && \
   cp $0 ${srcinstdir}/`basename $0` && \
   cd ${srcinstdir} && \
   tar cvjf ${src_pkg} *
